@@ -2,7 +2,7 @@
 #
 # Copyright (C) 2002  Masato Taruishi <taru@debian.org>
 # Copyright (C) 2006-2008  Junichi Uekawa <dancer@debian.org>
-# Copyright (C) 2008-2011  Francesco Poli <invernomuto@paranoici.org>
+# Copyright (C) 2008-2012  Francesco Poli <invernomuto@paranoici.org>
 # Copyright (C) 2009-2010  Ryan Niebur <ryan@debian.org>
 #
 #  This program is free software; you can redistribute it and/or modify
@@ -51,7 +51,7 @@ class AppConfig
       sprintf(_(" -H <hostname>    : Hostname of Debian Bug Tracking System [%s].\n"), @hostname),
       sprintf(_(" -p <port>        : Port number of the server [%s].\n"), @port),
       sprintf(_(" -P <priority>    : Specifies Pin-Priority value [%s].\n"), @pin_priority),
-      _(" -E <title>       : Specifies the title of rss output.\n"),
+      _(" -E <title>       : Specifies the title of RSS output.\n"),
       _(" -q               : Don't display progress bar.\n"),
       _(" -C <apt.conf>    : Specify apt.conf.\n"),
       _(" -y               : Assume that you select yes for all questions.\n"),
@@ -60,7 +60,7 @@ class AppConfig
       _("Commands:\n"),
       _(" apt              : Apt mode.\n"),
       _(" list <pkg...>    : List bug reports of the specified packages.\n"),
-      _(" rss <pkg...>     : List bug reports of the specified packages in rss.\n"),
+      _(" rss <pkg...>     : List bug reports of the specified packages in RSS.\n"),
       _("See the manual page for the long options.\n")
   end
 
@@ -229,6 +229,19 @@ class AppConfig
       exit 1
     end
 
+    if @command == "apt"
+      begin
+        test_tty = File.open("/dev/tty")
+        test_tty.close if test_tty
+      rescue
+        if @yes.nil?
+          $stderr.puts _("W: cannot open /dev/tty - running inside su -c \"command\"? Switching to non-interactive failure mode (see /usr/share/doc/apt-listbugs/README.Debian.gz)")
+          @yes = false
+        end
+        @quiet = true
+      end
+    end
+
     @parser =
       Debian::BTS::Parser::SoapIndex.new(@hostname, @port)
 
@@ -433,7 +446,12 @@ class Viewer
             }
 	  end
 	  if pkgs.size != 0
-	    if @config.frontend.yes_or_no? sprintf(ngettext("The following %d package will be pinned or on hold:\n %s\nAre you sure?", "The following %d packages will be pinned or on hold:\n %s\nAre you sure?", pkgs.size), pkgs.size, pkgs.keys.join(', '))
+            if @config.frontend.yes_or_no? ngettext(
+             # TRANSLATORS: %{plist} is a comma-separated list of %{npkgs} packages to be pinned or put on hold.
+             "The following package will be pinned or on hold:\n %{plist}\nAre you sure?",
+             "The following %{npkgs} packages will be pinned or on hold:\n %{plist}\nAre you sure?",
+             pkgs.size) % {:npkgs => pkgs.size,
+                           :plist => pkgs.keys.join(', ')}
 	      if key == "h"
                 h = on_hold(pkgs.keys)
               else
@@ -447,17 +465,17 @@ class Viewer
 	else
 	  if hold_pkgs.empty?
 	    @config.frontend.puts "" +
-              _("     y     - continue the apt installation, but do not make the bugs ignored.\n") +
-              _("     a     - continue the apt installation and make all the above bugs ignored.\n")
+              _("     y     - continue the apt installation, but do not mark the bugs as ignored.\n") +
+              _("     a     - continue the apt installation and mark all the above bugs as ignored.\n")
 	  end
 	  @config.frontend.puts "" +
 	    _("     n     - stop the apt installation.\n") +
 	    _("   <num>   - query the specified bug number (requires reportbug).\n") +
 	    _("  #<num>   - same as <num>\n") +
 	    _("     r     - redisplay bug lists.\n") +
-	    _(" p <pkg..> - make pkgs pinned: need to restart apt to enable.\n") +
-	    _(" p         - make all the above pkgs pinned: need to restart.\n") +
-	    _(" i <num>   - make bug number <num> ignored.\n") +
+	    _(" p <pkg..> - pin pkgs (restart APT session to enable).\n") +
+	    _(" p         - pin all the above pkgs (restart APT session to enable).\n") +
+	    _(" i <num>   - mark bug number <num> as ignored.\n") +
 	    _("     ?     - print this help.\n")
 	  if @config.browser != nil
 	    @config.frontend.puts sprintf(_("     w     - display bug lists in HTML (uses %s).\n"), File.basename(@config.browser))
@@ -485,23 +503,18 @@ class Viewer
           pin_ver = "*"
           pin_pri = "-30000"
 	end
-	holdstr << "
-Explanation: Pinned by apt-listbugs at #{Time.now}"
+        holdstr << "\nExplanation: Pinned by apt-listbugs at #{Time.now}"
         bugs_of_pkg( bugs, pkg ).each { |bug|
-	  holdstr << "
-Explanation:   ##{bug.bug_number}: #{bug.desc}"
+          holdstr << "\nExplanation:   ##{bug.bug_number}: #{bug.desc}"
         }
-	holdstr << "
-Package: #{pkg}
-Pin: version #{pin_ver}
-Pin-Priority: #{pin_pri}
-"
+        holdstr << "\nPackage: #{pkg}\nPin: version #{pin_ver}"
+        holdstr << "\nPin-Priority: #{pin_pri}\n"
       }
       $stderr.puts holdstr if $DEBUG
       if holdstr != ""
         File.open("/etc/apt/preferences", "a") { |io|
           io.puts holdstr
-	  @config.frontend.puts sprintf(_("%s pinned by adding Pin preferences in /etc/apt/preferences. You need to restart apt to enable"), pkgs.join(' '))
+	  @config.frontend.puts sprintf(_("%s pinned by adding Pin preferences in /etc/apt/preferences. Restart APT session to enable"), pkgs.join(' '))
 	  return pkgs
         }
       end
@@ -514,7 +527,7 @@ Pin-Priority: #{pin_pri}
         holdstr << "#{pkg} hold\n"
       }
       if system("echo '#{holdstr}' | dpkg --set-selections")
-        @config.frontend.puts sprintf(_("%s held: you need to restart apt to enable"), pkgs.join(' '))
+        @config.frontend.puts sprintf(_("%s held. Restart APT session to enable"), pkgs.join(' '))
         return pkgs
       end
       return nil
@@ -535,7 +548,9 @@ Pin-Priority: #{pin_pri}
 	      bugs_statistics[pkg] += 1
 	      p_bug_numbers << bug.bug_number
 	      if bug_exist == 0
-		buf = sprintf(_("%s bugs of %s ("), severity, pkg)
+                # TRANSLATORS: %{sevty} is the severity of some of the bugs found for package %{packg}.
+                buf = _("%{sevty} bugs of %{packg} (") % {:sevty => severity,
+                                                          :packg => pkg}
 		buf += "#{cur_pkgs[pkg]['version']} " if cur_pkgs[pkg] != nil
 		buf += "-> #{new_pkgs[pkg]['version']}) <#{@config.statmap(bug.stat)}>"
 		@config.frontend.puts buf
@@ -560,8 +575,10 @@ Pin-Priority: #{pin_pri}
       stat_str_ary = []
       bugs_statistics.each { |pkg, num|
 	if num > 0
-          # TRANSLATORS: the %s is the package name, and the %d is the number of bugs found for that package.
-          buf = sprintf(ngettext("%s(%d bug)", "%s(%d bugs)", num), pkg, num)
+          # TRANSLATORS: %{nbugs} is the number of bugs found for package %{packg}.
+          buf = ngettext("%{packg}(%{nbugs} bug)",
+                         "%{packg}(%{nbugs} bugs)", num) % {:packg => pkg,
+                                                            :nbugs => num}
 	  stat_str_ary << buf
 	end
       }
@@ -579,8 +596,8 @@ Pin-Priority: #{pin_pri}
 	if sub.size > 0
 	  o.puts "<table border=2 width=100%>"
           # TRANSLATORS: %s is a bug status such as forwarded, done, pending, pending-fixed, etc. see the -S option in the man page.
-          o.puts sprintf(_(" <caption>Bug reports which are marked as %s in the bug tracking system</caption>"), stat)
-	  o.puts _(" <tr><th>package</th><th>severity</th><th>bug number</th><th>description</th></tr>")
+          o.puts sprintf(" <caption>" + _("Bug reports which are marked as %s in the bug tracking system") + "</caption>", stat)
+          o.puts " <tr><th>" + _("package") + "</th><th>" + _("severity") + "</th><th>" + _("bug number") + "</th><th>" + _("description") + "</th></tr>"
 	  yield sub
 	  o.puts "</table><br>"
 	end
@@ -594,10 +611,10 @@ Pin-Priority: #{pin_pri}
       displayed_pkgs = []
 
       tmp = HtmlTempfile.new("apt-listbugs")
-      tmp.puts "<html><head><title>"+_("critical bugs for your upgrade")+"</title><meta http-equiv=\"Content-Type\" content=\"text/html; charset=#{Locale.charset}\"></head><body>"
-      tmp.puts _("<h1 align=\"center\">Critical bugs for your upgrade</h1>")
-      tmp.puts _("<p align=\"right\">by apt-listbugs</p><hr>")
-      tmp.puts _("<h2>Bug reports</h2>")
+      tmp.puts "<html><head><title>" + _("Critical bugs for your upgrade") + "</title><meta http-equiv=\"Content-Type\" content=\"text/html; charset=#{Locale.charset}\"></head><body>"
+      tmp.puts "<h1 align=\"center\">" + _("Critical bugs for your upgrade") + "</h1>"
+      tmp.puts "<p align=\"right\">" + _("by apt-listbugs") + "</p><hr>"
+      tmp.puts "<h2>" + _("Bug reports") + "</h2>"
 
       each_state_table(tmp, bugs, @config.stats) { |bugs|
 	bugs.each { |bug|
@@ -606,7 +623,7 @@ Pin-Priority: #{pin_pri}
         }
       }
 
-      tmp.puts _("<h2>Package upgrade information in question</h2>")
+      tmp.puts "<h2>" + _("Package upgrade information in question") + "</h2>"
       tmp.puts "<ul>"
       displayed_pkgs.each { |pkg|
 	tmp.puts "<li>#{pkg}("
@@ -620,10 +637,7 @@ Pin-Priority: #{pin_pri}
       tmp.close
 
       puts "Invoking browser for #{tmp.path}" if $DEBUG
-      browsercommandline = ""
-      browsercommandline << "su #{ENV["SUDO_USER"]} -c \"" if ENV["SUDO_USER"]
-      browsercommandline << "#{@config.browser} #{tmp.path} < /dev/tty"
-      browsercommandline << "\"" if ENV["SUDO_USER"]
+      browsercommandline = "#{@config.browser} #{tmp.path} < /dev/tty"
       if system(browsercommandline)
         puts "successfully invoked browser" if $DEBUG
       else
