@@ -1,6 +1,7 @@
 #
 # bug.rb - ruby interface for debian bug
 # Copyright (c) 2002 Masato Taruishi <taru@debian.org>
+# Copyright (c) 2006-2007 Junichi Uekawa <dancer@debian.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -32,6 +33,8 @@ module Debian
       @mergeids = mergeids
       @log = nil
       @time = time
+      @found = nil
+      @fixed = nil
     end
 
     def to_s
@@ -45,33 +48,32 @@ module Debian
 	@stat + " - " +
 	@tags.to_s + " - " + 
 	@desc + " merged with: " + @mergeids.join(', ') +
+	@found.to_s + " - " + 
+	@fixed.to_s + " - " + 
 	@time.to_s
     end
-    
+
     attr_accessor :pkg_name, :bug_number, :severity,
-      :stat, :desc, :tags, :mergeids, :log, :time
+    :stat, :desc, :tags, :mergeids, :log, :time, :found, :fixed
     
   end
   
   class Bugs < Array
-
+    
     def each_by_category (pkg, sev, stat)
-      each do |bug|
+      each { |bug|
 	yield bug if bug.pkg_name == pkg &&
 	  bug.severity == sev &&
 	  bug.stat == stat
-      end
+      }
     end
-
+    
     def sub(type, val)
       sub = Bugs.new
-      each do |bug|
-	a = "sub << bug if bug.#{type} == val"
-	eval a
-      end
+      each { |bug|
+        sub << bug if bug.send(type) == val
+      }
       sub
     end
-
   end
-
 end
